# YouTube Lounge API wrapper written in Python

[![GitHub Release](https://img.shields.io/github/v/release/FabioGNR/pyytlounge)](https://github.com/FabioGNR/pyytlounge/releases)
[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/FabioGNR/pyytlounge/test.yml)](https://github.com/FabioGNR/pyytlounge/actions)
[![Documentation Status](https://readthedocs.org/projects/pyytlounge/badge/?version=latest)](https://pyytlounge.readthedocs.io/en/latest/?badge=latest)

## Setup

Activate virtual environment:

- create `python -m venv .venv`
- activate `source .venv/bin/activate`
- install package and its requirements `pip install -e .`

## How to use

`python test.py` will run an interactive demo.
View documentation on [readthedocs.io](https://pyytlounge.readthedocs.io/en/latest/?badge=latest).

## Release Notes

See [CHANGELOG](CHANGELOG.md).

## Thanks

- https://github.com/henriquekano/youtube-lounge-api
